aboutsummaryrefslogtreecommitdiff
path: root/video/qt_decoder.h
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/qt_decoder.h
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/qt_decoder.h')
-rw-r--r--video/qt_decoder.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/video/qt_decoder.h b/video/qt_decoder.h
index ed6634e38c..ef701b3756 100644
--- a/video/qt_decoder.h
+++ b/video/qt_decoder.h
@@ -49,7 +49,7 @@ namespace Common {
class MacResManager;
}
-namespace Graphics {
+namespace Video {
/**
* Decoder for QuickTime videos.
@@ -113,11 +113,11 @@ public:
void setChunkBeginOffset(uint32 offset) { _beginOffset = offset; }
bool isVideoLoaded() const { return _fd != 0; }
- const Surface *decodeNextFrame();
+ const Graphics::Surface *decodeNextFrame();
bool endOfVideo() const;
uint32 getElapsedTime() const;
uint32 getTimeToNextFrame() const;
- PixelFormat getPixelFormat() const;
+ Graphics::PixelFormat getPixelFormat() const;
// SeekableVideoDecoder API
void seekToFrame(uint32 frame);
@@ -247,8 +247,8 @@ private:
int8 _videoStreamIndex;
uint32 findKeyFrame(uint32 frame) const;
- Surface *_scaledSurface;
- const Surface *scaleSurface(const Surface *frame);
+ Graphics::Surface *_scaledSurface;
+ const Graphics::Surface *scaleSurface(const Graphics::Surface *frame);
Common::Rational getScaleFactorX() const;
Common::Rational getScaleFactorY() const;
@@ -273,6 +273,6 @@ private:
int readWAVE(MOVatom atom);
};
-} // End of namespace Graphics
+} // End of namespace Video
#endif